@@ -1,6 +1,9 @@
-from functools import cached_property
+from a_sync.functools import cached_property_unsafe as cached_property
 
-MODES = ["default", "application", "infura"]
+from typing_extensions import Self
+
+
+MODES = "default", "application", "infura"
 
 
 class OperationMode(str):
@@ -38,7 +41,7 @@ class OperationMode(str):
         return self.mode == "infura"
 
     @property
-    def mode(self):
+    def mode(self) -> Self:
         """
         Retrieves the current operation mode.
 
